@@ -55,7 +55,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'איזור זמן לאורחים',
 	'SYSTEM_TIMEZONE_EXPLAIN'			=> 'איזור זמן המוצג למשתמשים לא מחוברים (אורחים, בוטים). משתמשים מחוברים מגדירים את איזור הזמן שלהם במהלך ההרשמה ויכולים לשנות אותו מלוח הבקרה למשתמש.',
 	'WARNINGS_EXPIRE'				=> 'תקופת אזהרה',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'מספר ימים שיעברו לפני שתקופת האזהרה תסתיים אוטומטית מרשומת משתמש.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'מספר ימים שיעברו לפני שתקופת האזהרה תסתיים אוטומטית מרשומת משתמש. קבע ערך זה ל0 כדי להפוך את האזהרה לקבועה.',
 ));
 
 // Board Features
@@ -176,7 +176,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'מספר קישורים מירבי לכל הודעה',
 	'MAX_POST_URLS_EXPLAIN'			=> 'מספר מירבי של קישורים בהודעה.  כאשר 0 הינו לא מוגבל.',
 	'MIN_CHAR_LIMIT'				=> 'מספר תווים מינימלי להודעה',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'מספר התווים המינימלי שמשתמש צריך לכתוב בהודעה/הודעה פרטית.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'מספר התווים המינימלי שמשתמש צריך לכתוב בהודעה/הודעה פרטית. המינימום להגדרה זו הוא 1.',
 	'POSTING'						=> 'שליחה',
 	'POSTS_PER_PAGE'				=> 'הודעות לכל עמוד',
 	'QUOTE_DEPTH_LIMIT'				=> 'כמות מירבית לציטוטים בתוך ציטוטים.',
