@@ -297,9 +297,9 @@ $lang = array_merge($lang, array(
 
 // Logs
 $lang = array_merge($lang, array(
-	'ACP_ADMIN_LOGS_EXPLAIN'	=> 'עמוד זה רושם את כל הפעולות אשר התבצעו על-ידי המנהלים הראשיים של המערכת. אתה יכול למיין לפי שם משתמש, תאריך, IP או פעולה. אם יש לך את ההרשאות המתאימות, אתה יכול להסיר פעולות מסוימות או את מעקב הפעולות בשלמותו.',
-	'ACP_CRITICAL_LOGS_EXPLAIN'	=> 'עמוד זה רושם את כל הפעולות אשר התבצעו על-ידי המערכת עצמה. המעקב פעולות מספק לך מידע אשר תוכל להשתמש בו לפתירת בעיות מסויימות, למשל אי-מסירת הודעות דואר אלקטרוני. אתה יכול למיין לפי שם משתמש, תאריך, IP או פעולה. אם יש לך את ההרשאות המתאימות, אתה יכול להסיר פעולות מסוימות או את מעקב הפעולות בשלמותו.',
-	'ACP_MOD_LOGS_EXPLAIN'		=> 'עמוד זה רושם את כל הפעולות אשר התבצעו בפורומים, נושאים והודעות וכמו כן פעולות שהתצבעו על משתמשים על-ידי מנהלים, כולל חסימה. אתה יכול למיין לפי שם משתמש, תאריך, IP או פעולה. אם יש לך את ההרשאות המתאימות, אתה יכול להסיר פעולות מסוימות או את המעקב הפעולות בשלמותו.',
+	'ACP_ADMIN_LOGS_EXPLAIN'	=> 'עמוד זה רושם את כל הפעולות אשר התבצעו על-ידי המנהלים הראשיים של המערכת. אתה יכול למיין לפי שם משתמש, תאריך, IP או פעולה. אם יש לך את ההרשאות המתאימות, אתה יכול להסיר פעולות מסויות או את מעקב הפעולות בשלמותו.',
+	'ACP_CRITICAL_LOGS_EXPLAIN'	=> 'עמוד זה רושם את כל הפעולות אשר התבצעו על-ידי המערכת עצמה. המעקב פעולות מספק לך מידע אשר תוכל להשתמש בו לפתירת בעיות מסויימות, למשל אי-מסירת הודעות דואר אלקטרוני. אתה יכול למיין לפי שם משתמש, תאריך, IP או פעולה. אם יש לך את ההרשאות המתאימות, אתה יכול להסיר פעולות מסויות או את מעקב הפעולות בשלמותו.',
+	'ACP_MOD_LOGS_EXPLAIN'		=> 'עמוד זה רושם את כל הפעולות אשר התבצעו בפורומים, נושאים והודעות וכמו כן פעולות שהתצבעו על משתמשים על-ידי מנהלים, כולל חסימה. אתה יכול למיין לפי שם משתמש, תאריך, IP או פעולה. אם יש לך את ההרשאות המתאימות, אתה יכול להסיר פעולות מסויות או את המעקב הפעולות בשלמותו.',
 	'ACP_USERS_LOGS_EXPLAIN'	=> 'עמוד זה רושם את כל הפעולות אשר התבצעו על-ידי משתמשים או על משתמשים (דיווחים, אזהרות והודעות משתמש).',
 	'ALL_ENTRIES'				=> 'כל הרישומים',
 
@@ -325,6 +325,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'שרת בסיס נתונים',
 	'DATABASE_SIZE'			=> 'גודל בסיס נתונים',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'פנקציית  overloading הוגדרה לא נכון',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> חייב להיות מוגדר ל0 או ל4. אתה יכול לבדוק את הערך הנוכחי בעמוד <samp>פרטי PHP</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'קידוד תכונת השקיפות הוגדר לא נכון',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> חייב להיות מוגדר ל0. אתה יכול לבדוק את הערך הנוכחי בעמוד <samp>פרטי PHP</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'ממיר תכונת הקלט של HTTP הוגדר לא נכון',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> חייב להיות מוגדר ל <samp>pass</samp>. אתה יכול לבדוק את הערך הנוכחי בעמוד <samp>פרטי PHP</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'ממיר תכונת הפלט של HTTP הוגדר לא נכון',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> חייב להיות מוגדר ל <samp>pass</samp>. אתה יכול לבדוק את הערך הנוכחי בעמוד <samp>פרטי PHP</samp>.',
+
 	'FILES_PER_DAY'		=> 'קבצים מצורפים ליום',
 	'FORUM_STATS'		=> 'סטטיסטיקות המערכת',
 
