@@ -107,7 +107,7 @@ $lang = array_merge($lang, array(
 	'BOARD_BAN_TIME'		=> 'נחסמת מהמערכת עד <strong>%1$s</strong>.<br /><br />צור קשר עם %2$sהמנהל הראשי%3$s למידע נוסף.',
 	'BOARD_DISABLE'			=> 'מערכת הפורומים אינה זמינה כרגע. עמכם הסליחה.',
 	'BOARD_DISABLED'		=> 'המערכת כבויה כרגע.',
-	'BOARD_UNAVAILABLE'		=> 'סליחה, אך המערכת אינה זמינה כרגע, אנא נסה שוב בעוד מספר דקות.',
+	'BOARD_UNAVAILABLE'		=> 'אבל המערכת אינה זמינה באופן זמני, אנא נסה שוב בעוד מספר דקות.',
 	'BROWSING_FORUM'      => 'משתמשים הגולשים בפורום זה: %1$s',
 	'BROWSING_FORUM_GUEST'	=> 'משתמשים הגולשים בפורום זה: %1$s ואורח אחד',
 	'BROWSING_FORUM_GUESTS'	=> 'משתמשים הגולשים בפורום זה: %1$s ו %2$d אורחים',
@@ -166,6 +166,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'יש לציין כותרת בעת שליחת הודעה חדשה.',
 	'ENABLED'							=> 'מופעל',
 	'ENCLOSURE'							=> 'סגור',
+	'ENTER_USERNAME'					=> 'הזן שם משתמש',
 	'ERR_CHANGING_DIRECTORY'			=> 'לא ניתן לשנות תיקיה.',
 	'ERR_CONNECTING_SERVER'				=> 'שגיאה בהתחברות לשרת.',
 	'ERR_JAB_AUTH'						=> 'לא ניתן לאמת בשרת Jabber.',
@@ -201,7 +202,8 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'אנא לחץ כאן על מנת לצפות בחוקי הפורום',
 	'FROM'					=> 'מאת',
 	'FSOCK_DISABLED'		=> 'לא ניתן להשלים את הפעולה מפני שהפונקציה <var>fsockopen</var> כבויה או שהשרת שהתבקש לא נמצא.',
-
+	'FSOCK_TIMEOUT'			=> 'נוצר פסק זמן במהלך הקריאה מהרשת.',
+	
 	'FTP_FSOCK_HOST'				=> 'שרת FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'שרת ה-FTP המשמש להתחברות לאתר שלך.',
 	'FTP_FSOCK_PASSWORD'			=> 'סיסמה ל-FTP',
@@ -648,6 +650,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> הודעות שלא נקראו',
 	'UNREAD_POST'			=> 'הודעה שלא נקראה',
 	'UNREAD_POSTS'			=> 'הודעות שלא נקראו',
+	'UNWATCH_FORUM_CONFIRM'		=> 'האם אתה בטוח שברצונך לבטל את הרישום לפורום זה?',
+	'UNWATCH_FORUM_DETAILED'	=> 'האם אתה בטוח שברצונך לבטל את הרישום מפורום “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'האם אתה בטוח שברצונך לבטל את הרישום מנושא זה?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'האם אתה בטוח שברצונך לבטל את הרישום מנושא “%s”?',
 	'UNWATCHED_FORUMS'		=> 'אינך רשום יותר לעדכונים לפורומים שנבחרו.',
 	'UNWATCHED_TOPICS'		=> 'אינך רשום יותר לעדכונים לנושאים שנבחרו.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'אינך רשום יותר לקבלת עדכונים בפריטים הנבחרים.',
@@ -695,6 +701,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'אזהרות',
 	'WARN_USER'			=> 'הזהר משתמש',
+	'WATCH_FORUM_CONFIRM'	=> 'האם אתה בטוח שברצונך להרשם לפורום זה?',
+	'WATCH_FORUM_DETAILED'	=> 'האם אתה בטוח שברצונך להרשם לפורום “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'האם אתה בטוח שברצונך להרשם לנושא זה?',
+	'WATCH_TOPIC_DETAILED'	=> 'האם אתה בטוח שברצונך להרשם לנושא “%s”?',
 	'WELCOME_SUBJECT'	=> 'ברוך הבא לפורום %s',
 	'WEBSITE'			=> 'אתר בית',
 	'WHOIS'				=> 'מי זה',
