@@ -62,7 +62,7 @@ $help = array(
 	),
 	array(
 		0 => 'נרשמתי בעבר אבל אני לא מצליח להתחבר יותר?!',
-		1 => 'לא מצליח לאתר את כתובת הדואר האלקטרוני שהזנת, בדוק את שם המשתמש והסיסמה ונסה שנית. יכול להיות שמנהלי המערכת ביטלו את חשבונך או הסירו אותו מן המערכת. בנוסף, יכול להיות שהמערכת הסירה משתמשים אשר לא היו פעילים זמן רב. במידה וזה אכן קרה, נסה להרשם שוב, ותיהיה יותר פעיל בדיונים.'
+		1 => 'קיימת אפשרות שמנהל ראשי כיבה או מחק את חשבונך מסיבה כלשהי. בנוסף, פורומים רבים מוחקים משתמשים אשר לא פירסמו הודעות זמן רב כדי לצמצם בגודל של בסיס הנתונים. אם זה קרה, נסה להרשם שוב ולהיות יותר פעיל בדיונים.'
 	),
 	array(
 		0 => 'מהו COPPA?',
