@@ -63,6 +63,7 @@ $lang = array_merge($lang, array(
 	'CAT_UPDATE'				=> 'עדכון',
 	'CHANGE'					=> 'שנה',
 	'CHECK_TABLE_PREFIX'		=> 'בדוק את קידומת הטבלאות שלך ונסה שנית.',
+	'TABLE_PREFIX_EXPLAIN'		=> 'הקידומת חייבת להתחיל באות, ויכולה להכיל אותיות, מספרים וקו תחתון בלבד.',
 	'CLEAN_VERIFY'				=> 'מנקה ומוודא את המבנה הסופי',
 	'CLEANING_USERNAMES'		=> 'מנקה שמות משתמשים',
 	'COLLIDING_CLEAN_USERNAME'	=> '<strong>%s</strong> הוא שם המשתמש החדש של:',
@@ -152,7 +153,7 @@ $lang = array_merge($lang, array(
 	'DLL_MYSQL'					=> 'MySQL',
 	'DLL_MYSQLI'				=> 'MySQL עם סיומת MySQLi',
 	'DLL_ORACLE'				=> 'Oracle',
-	'DLL_POSTGRES'				=> 'PostgreSQL 7.x/8.x',
+	'DLL_POSTGRES'				=> 'PostgreSQL',
 	'DLL_SQLITE'				=> 'SQLite',
 	'DLL_XML'					=> 'תמיכה ב XML [ Jabber ]',
 	'DLL_ZLIB'					=> 'תמיכה בדחיסת zlib [ gz, .tar.gz, .zip ]',
@@ -231,6 +232,7 @@ $lang = array_merge($lang, array(
 	'INST_ERR'					=> 'שגיאת התקנה',
 	'INST_ERR_DB_CONNECT'		=> 'לא ניתן להתחבר לבסיס הנתונים, ראה הודעת שגיאה להלן.',
 	'INST_ERR_DB_FORUM_PATH'	=> 'קובץ בסיס הנתונים שצוין נמצא בתוך עץ תיקיות המערכת. אתה צריך לשים קובץ זה במיקום לא נגיש.',
+	'INST_ERR_DB_INVALID_PREFIX'=> 'הקידומת שהזנת לא חוקית. היא  חייבת להתחיל באות, ויכולה להכיל אותיות, מספרים וקו תחתון בלבד.',
 	'INST_ERR_DB_NO_ERROR'		=> 'לא ניתנה הודעת שגיאה.',
 	'INST_ERR_DB_NO_MYSQLI'		=> 'הגרסה של MySQL המותקנת על שרת זה אינה מותאמת לאפשרות “MySQL עם סיומת MySQLi” אשר בחרת. נסה את האפשרות “MySQL” במקום זאת.',
 	'INST_ERR_DB_NO_SQLITE'		=> 'הגרסה של סיומת SQLite אשר התקנת ישנה מדי, אתה חייב לשדרג אותה לפחות לגרסה 2.8.2.',
@@ -491,7 +493,7 @@ $lang = array_merge($lang, array(
 	'SHOW_DIFF_NEW'				=> 'הצג תוכן קובץ',
 	'SHOW_DIFF_NEW_CONFLICT'	=> 'הצג הבדלים',
 	'SHOW_DIFF_NOT_MODIFIED'	=> 'הצג הבדלים',
-	'SOME_QUERIES_FAILED'		=> 'כמה שאילתות נכשלו, המשפטים והשגיאות רשומים להלן.',
+	'SOME_QUERIES_FAILED'		=> 'כמה שאילתות נכשלו, המשפטים והשגיאות רשומים מטה.',
 	'SQL'						=> 'SQL',
 	'SQL_FAILURE_EXPLAIN'		=> 'כנראה שזו לא סיבה לדאגה, העדכון ימשיך. במידה והשגיאה פגעה בהשלמת התהליך תוכל לבקש תמיכה בפורומי התמיכה שלנו. ראה <a href="../docs/README.html">README</a> לפרטים כל כיצד לקבל יעוץ.',
 	'STAGE_FILE_CHECK'			=> 'בדיקת קבצים',
