@@ -139,6 +139,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'תמונה נוכחית',
 	'CURRENT_PASSWORD'			=> 'סיסמה נוכחית',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'אתה חייב לאשר את סיסמתך הנוכחית אם אתה מעונין לשנות אותה, לשנות את כתובת הדואר האלקטרוני או שם המשתמש.',
+	'CUR_PASSWORD_EMPTY'		=> 'לא הזנת את הסיסמא הנוכחית.',
 	'CUR_PASSWORD_ERROR'		=> 'הסיסמה הנוכחית שהזנת שגויה.',
 	'CUSTOM_DATEFORMAT'			=> 'מותאם אישית…',
 
@@ -269,9 +270,11 @@ $lang = array_merge($lang, array(
 	'MOVE_TO_FOLDER'				=> 'העבר לתיקיה',
 	'MOVE_UP'						=> 'העבר למעלה',
 
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'לא הזנת אישור כתובת דואר אלקטרוני.',
 	'NEW_EMAIL_ERROR'				=> 'כתובות הדואר האלקטרוני שהזנת אינן תואמות.',
 	'NEW_FOLDER_NAME'				=> 'השם החדש לתיקיה',
 	'NEW_PASSWORD'					=> 'סיסמה חדשה',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'לא הזנת את הסיסמא שוב.',
 	'NEW_PASSWORD_ERROR'			=> 'הסיסמאות  שהזנת אינן תואמות.',
 	'NOTIFY_METHOD'					=> 'שיטת הודעה',
 	'NOTIFY_METHOD_BOTH'			=> 'שניהם',
